# .github/.copilot-instructions.md

## Only apply the following rules based on specific file types

- "*.md": "docs/rules/markdown-rules.md"
- "*.mdc": "docs/rules/markdown-rules.md"
- "*.py": "docs/rules/python-github-rules.md"
- "*.tf": "docs/rules/terraform-coding-rules.md"

## Always apply the following rules for session memory

- "session_memory": "docs/rules/chroma-memory-rules.md"

## Always apply the following context validation rules

- Always check the context before starting a new task (use Session Memory Rules).
- In case of multiple steps required, consider using thinking tools to break down the task, if applicable.
- At the end of each session, summarize the context (use Session Memory Rules)
- Finish each output listing which rulesets have been applied.
